# hooly-utils-kit-py

from hooly_utils_kit import Validators, Formatters

Eg..
    Formatters.format_phone_number("")
    Validators.validate_date("")

### Validators
    - validate_date = validates that the date is correct
    - is_composed_of_numbers = valid if data is composed of numbers
    - is_rut_valid = valid that the rut is valid

### Formatters
    - format_phone_number = format a number to chilean phone number
    - format_to_datetime = format a date to datetime